@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2023 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2025 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -18,7 +18,7 @@
 dvMF3 <-
   function(x, colatitude, longitude, concentration,
            byrow.arg = FALSE, log = FALSE) {
-  if (!is.logical(log.arg <- log) || length(log) != 1)
+  if (!isFALSE(log.arg <- log) && !isTRUE(log))
     stop("bad input for argument 'log'")
   rm(log)
 
@@ -27,14 +27,14 @@ dvMF3 <-
   if (!is.matrix(x))
     x <- as.matrix(x)
   LLL <- max(nrow(x), length(colatitude),
-             length(colatitude), length(concentration))
-  if (nrow(x) != LLL)
+             length(longitude), length(concentration))
+  if (nrow(x) < LLL)
     x <- matrix(as.vector(x), LLL, 2, byrow = byrow.arg)
-  if (length(longitude) != LLL)
+  if (length(longitude) < LLL)
     longitude <- rep_len(longitude, LLL)
-  if (length(colatitude) != LLL)
+  if (length(colatitude) < LLL)
     colatitude <- rep_len(colatitude, LLL)
-  if (length(concentration) != LLL)
+  if (length(concentration) < LLL)
     concentration <- rep_len(concentration, LLL)
   
   bad0 <- !is.finite(colatitude) | !is.finite(longitude) |
@@ -69,8 +69,8 @@ dvMF3 <-
 
 
  vMF3 <-
-  function(lcolati = extlogitlink(min = -pi, max = pi),  #"identitylink",
-           llongit = extlogitlink(min = -pi, max = pi),  #"identitylink",
+  function(lcolati = "extlogitlink(min = -pi, max = pi)",  #"identitylink",
+           llongit = "extlogitlink(min = -pi, max = pi)",  #"identitylink",
            lconcen = "loglink",  # "logitlink",
            icolati = NULL, ilongit = NULL, iconcen = NULL,
            gcolati = exp(2*ppoints(5) - 1),
@@ -78,12 +78,20 @@ dvMF3 <-
            gconcen = exp(2*ppoints(5) - 1),
            tol12 = 1.0e-4,
            zero = NULL) {
+  if (is.character(lcolati))
+    lcolati <- substitute(y9, list(y9 = lcolati))
   lcolati <- as.list(substitute(lcolati))
   ecolati <- link2list(lcolati)
   lcolati <- attr(ecolati, "function.name")
+
+  if (is.character(llongit))
+    llongit <- substitute(y9, list(y9 = llongit))
   llongit <- as.list(substitute(llongit))
   elongit <- link2list(llongit)
   llongit <- attr(elongit, "function.name")
+
+  if (is.character(lconcen))
+    lconcen <- substitute(y9, list(y9 = lconcen))
   lconcen <- as.list(substitute(lconcen))
   econcen <- link2list(lconcen)
   lconcen <- attr(econcen, "function.name")
@@ -180,8 +188,6 @@ dvMF3 <-
                        y = yvec, w = wvec,
                        ret.objfun = TRUE)  # Last value is the loglik
 
- print("try.this")
- print( try.this )
           concen.init[, spp.] <- try.this["Value1" ]
           colati.init[, spp.] <- try.this["Value2" ]
           longit.init[, spp.] <- try.this["Value3" ]
@@ -267,9 +273,9 @@ dvMF3 <-
     concen=eta2theta(eta[, c(FALSE, FALSE, TRUE)], .lconcen , .econcen )
     rvMF3(nsim * length(colati), colati = colati,
           longit = longit, concen = concen)
-  }, list(
-     .lcolati = lcolati, .llongit = llongit, .lconcen = lconcen,
-     .ecolati = ecolati, .elongit = elongit, .econcen = econcen ))),
+  },
+  list( .lcolati = lcolati, .llongit = llongit, .lconcen = lconcen,
+        .ecolati = ecolati, .elongit = elongit, .econcen = econcen ))),
   deriv = eval(substitute(expression({
     colati=eta2theta(eta[, c(TRUE, FALSE, FALSE)], .lcolati , .ecolati )
     longit=eta2theta(eta[, c(FALSE, TRUE, FALSE)], .llongit , .elongit )
@@ -298,9 +304,9 @@ dvMF3 <-
                             dl.dlongit * dlongit.deta,
                             dl.dconcen * dconcen.deta)
     dl.deta[, interleave.VGAM(M, M1 = M1)]
-  }), list(
-      .lcolati = lcolati, .llongit = llongit, .lconcen = lconcen,
-      .ecolati = ecolati, .elongit = elongit, .econcen = econcen ))),
+  }),
+  list( .lcolati = lcolati, .llongit = llongit, .lconcen = lconcen,
+        .ecolati = ecolati, .elongit = elongit, .econcen = econcen ))),
   weight = eval(substitute(expression({
     ned2l.dcolati2 <- (-concen) * Akappa  # 1 - coth(concen) / concen
     ned2l.dlongit2 <- concen * Akappa * (sin(colati))^2
@@ -315,10 +321,10 @@ dvMF3 <-
                 dim = c(n, M / M1, 6))
     wz <- arwz2wz(wz, M = M, M1 = M1)
     wz
-  }), list(
-      .lcolati = lcolati, .llongit = llongit, .lconcen = lconcen,
-      .ecolati = ecolati, .elongit = elongit, .econcen = econcen,
-      .tol12 = tol12 ))))
+  }),
+  list( .lcolati = lcolati, .llongit = llongit, .lconcen = lconcen,
+        .ecolati = ecolati, .elongit = elongit, .econcen = econcen,
+        .tol12 = tol12 ))))
 }  # vMF3
 
 
@@ -327,15 +333,15 @@ dvMF3 <-
 
 
 dcard <- function(x, mu, rho, log = FALSE) {
-  if (!is.logical(log.arg <- log) || length(log) != 1)
+  if (!isFALSE(log.arg <- log) && !isTRUE(log))
     stop("bad input for argument 'log'")
   rm(log)
 
 
   L <- max(length(x), length(mu), length(rho))
-  if (length(x)   != L) x   <- rep_len(x,   L)
-  if (length(mu)  != L) mu  <- rep_len(mu,  L)
-  if (length(rho) != L) rho <- rep_len(rho, L)
+  if (length(x)   < L) x   <- rep_len(x,   L)
+  if (length(mu)  < L) mu  <- rep_len(mu,  L)
+  if (length(rho) < L) rho <- rep_len(rho, L)
 
   logdensity <- rep_len(log(0), L)
   xok <- (x > 0) & (x < (2*pi))
@@ -352,9 +358,9 @@ dcard <- function(x, mu, rho, log = FALSE) {
 
 pcard <- function(q, mu, rho, lower.tail = TRUE, log.p = FALSE) {
 
-  if (!is.logical(lower.tail) || length(lower.tail ) != 1)
+  if (!isFALSE(lower.tail) && !isTRUE(lower.tail))
     stop("bad input for argument 'lower.tail'")
-  if (!is.logical(log.p) || length(log.p) != 1)
+  if (!isFALSE(log.p) && !isTRUE(log.p))
     stop("bad input for argument 'log.p'")
 
   if (lower.tail) {
@@ -391,14 +397,14 @@ qcard <- function(p, mu, rho, tolerance = 1.0e-7, maxits = 500,
     stop("'p' must be between 0 and 1")
 
   nn <- max(length(p), length(mu), length(rho))
-  if (length(p)   != nn) p   <- rep_len(p,   nn)
-  if (length(mu)  != nn) mu  <- rep_len(mu,  nn)
-  if (length(rho) != nn) rho <- rep_len(rho, nn)
+  if (length(p)   < nn) p   <- rep_len(p,   nn)
+  if (length(mu)  < nn) mu  <- rep_len(mu,  nn)
+  if (length(rho) < nn) rho <- rep_len(rho, nn)
 
 
-  if (!is.logical(lower.tail) || length(lower.tail ) != 1)
+  if (!isFALSE(lower.tail) && !isTRUE(lower.tail))
     stop("bad input for argument 'lower.tail'")
-  if (!is.logical(log.p) || length(log.p) != 1)
+  if (!isFALSE(log.p) && !isTRUE(log.p))
     stop("bad input for argument 'log.p'")
 
   if (lower.tail) {
@@ -511,15 +517,19 @@ cardioid.control <- function(save.weights = TRUE, ...) {
 
 
  cardioid <- function(
-     lmu  = extlogitlink(min = 0, max = 2*pi),
-     lrho = extlogitlink(min = -0.5, max = 0.5),
+     lmu  = "extlogitlink(min = 0, max = 2*pi)",
+     lrho = "extlogitlink(min = -0.5, max = 0.5)",
      imu = NULL, irho = 0.3,
      nsimEIM = 100, zero = NULL) {
 
+  if (is.character(lmu))
+    lmu <- substitute(y9, list(y9 = lmu))
   lmu <- as.list(substitute(lmu))
   emu <- link2list(lmu)
   lmu <- attr(emu, "function.name")
 
+  if (is.character(lrho))
+    lrho <- substitute(y9, list(y9 = lrho))
   lrho <- as.list(substitute(lrho))
   erho <- link2list(lrho)
   lrho <- attr(erho, "function.name")
@@ -691,21 +701,26 @@ cardioid.control <- function(save.weights = TRUE, ...) {
     wz <- wz * dtheta.detas[, index0$row] *
                dtheta.detas[, index0$col]
     c(w) * wz
-  }), list( .lmu = lmu, .lrho = lrho,
-            .emu = emu, .erho = erho, .nsimEIM = nsimEIM ))))
+  }),
+  list( .lmu = lmu, .lrho = lrho,
+        .emu = emu, .erho = erho, .nsimEIM = nsimEIM ))))
 }
 
 
 
- vonmises <- function(llocation = extlogitlink(min = 0, max = 2*pi),
-                      lscale  = "loglink",
-                      ilocation = NULL, iscale  = NULL,
-                      imethod = 1, zero = NULL) {
-
+ vonmises <-
+  function(llocation = "extlogitlink(min = 0, max = 2*pi)",
+           lscale  = "loglink",
+           ilocation = NULL, iscale  = NULL,
+           imethod = 1, zero = NULL) {
+  if (is.character(llocation))
+    llocation <- substitute(y9, list(y9 = llocation))
   llocat <- as.list(substitute(llocation))
   elocat <- link2list(llocat)
   llocat <- attr(elocat, "function.name")
 
+  if (is.character(lscale))
+    lscale <- substitute(y9, list(y9 = lscale))
   lscale <- as.list(substitute(lscale))
   escale <- link2list(lscale)
   lscale <- attr(escale, "function.name")
@@ -832,15 +847,17 @@ cardioid.control <- function(save.weights = TRUE, ...) {
             .llocat = llocat, .elocat = elocat ))),
   weight = eval(substitute(expression({
     ned2l.dlocat2 <- Scale * tmp6[, 2] / tmp6[, 1]
-    ned2l.dscale2 <- tmp6[, 3] / tmp6[, 1] - (tmp6[, 2] / tmp6[, 1])^2
+    ned2l.dscale2 <- tmp6[, 3] / tmp6[, 1] -
+                    (tmp6[, 2] / tmp6[, 1])^2
 
     wz <- matrix(0, nrow = n, ncol = 2)  # diagonal
     wz[, iam(1, 1, M)] <- ned2l.dlocat2 * dlocat.deta^2
     wz[, iam(2, 2, M)] <- ned2l.dscale2 * dscale.deta^2
     c(w) * wz
-  }), list( .escale = escale, .elocat = elocat,
-            .lscale = lscale, .llocat = llocat ))))
-}
+  }),
+  list( .escale = escale, .elocat = elocat,
+        .lscale = lscale, .llocat = llocat ))))
+}  # vonmises
 
 
 
