@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2023 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2025 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -172,18 +172,18 @@
 
 
   skip <- vecTF.t | vecTF.a  # Leave these values alone
-  tmp6 <- 1 - sum.a - sum.i - pobs.mix - pstr.mix + sum.d + pdip.mix
-  if (li.mlm) {
+  tmp6 <- 1 - sum.a - sum.i - pobs.mix -
+          pstr.mix + sum.d + pdip.mix
     if (any(tmp6[!skip] < 0, na.rm = TRUE)) {
       warning("the vector of normalizing constants contains ",
               "some negative values. Replacing them with NAs")
       tmp6[!skip & tmp6 < 0] <- NA
     }
-  }  # li.mlm
 
 
+  denom1 <- cdf.max.s - sumt - suma
   pmf0[!skip] <-
-    (tmp6 * dzeta(x, shape.p) / (cdf.max.s - suma - sumt))[!skip]
+    (tmp6 * dzeta(x, shape.p) / denom1)[!skip]
 
 
 
@@ -210,11 +210,30 @@
 
 
 
+  if (any(vecTF <- !is.na(tmp6) & tmp6 <= 0)) {
+    pmf0[vecTF] <- NaN
+    pobs.mix[vecTF] <- NaN
+    pstr.mix[vecTF] <- NaN
+    pdip.mix[vecTF] <- NaN
+  }
+  if (any(vecTF <- !is.na(denom1) & denom1 <= 0)) {
+    pmf0[vecTF] <- NaN
+    pobs.mix[vecTF] <- NaN
+    pstr.mix[vecTF] <- NaN
+    pdip.mix[vecTF] <- NaN
+  }
+
+
 
   pmf0 <- pmf0 + pobs.mix * pmf2.a + pstr.mix * pmf2.i -
                  pdip.mix * pmf2.d
 
 
+  if (any(vecTF <- !is.na(pmf0) & pmf0 < 0))
+    pmf0[vecTF] <- NaN
+  if (any(vecTF <- !is.na(pmf0) & pmf0 > 1))
+    pmf0[vecTF] <- NaN
+
   if (log.arg) log(pmf0) else pmf0
 }  # dgaitdzeta
 
@@ -915,19 +934,19 @@
   }
 
   skip <- vecTF.t | vecTF.a  # Leave these values alone
-  tmp6 <- 1 - sum.a - sum.i - pobs.mix - pstr.mix + sum.d + pdip.mix
-  if (li.mlm) {
+  tmp6 <- 1 - sum.a - sum.i - pobs.mix -
+          pstr.mix + sum.d + pdip.mix
     if (any(tmp6[!skip] < 0, na.rm = TRUE)) {
       warning("the vector of normalizing constants contains ",
               "some negative values. Replacing them with NAs")
       tmp6[!skip & tmp6 < 0] <- NA
     }
-  }  # li.mlm
 
 
 
+  denom1 <- cdf.max.s - sumt - suma
   pmf0[!skip] <- (tmp6 *
-    dlog(x, shape.p) / (cdf.max.s - suma - sumt))[!skip]
+    dlog(x, shape.p) / denom1)[!skip]
 
 
 
@@ -952,9 +971,28 @@
   }  # ld.mlm
 
 
+  if (any(vecTF <- !is.na(tmp6) & tmp6 <= 0)) {
+    pmf0[vecTF] <- NaN
+    pobs.mix[vecTF] <- NaN
+    pstr.mix[vecTF] <- NaN
+    pdip.mix[vecTF] <- NaN
+  }
+  if (any(vecTF <- !is.na(denom1) & denom1 <= 0)) {
+    pmf0[vecTF] <- NaN
+    pobs.mix[vecTF] <- NaN
+    pstr.mix[vecTF] <- NaN
+    pdip.mix[vecTF] <- NaN
+  }
+
+
   pmf0 <- pmf0 + pobs.mix * pmf2.a + pstr.mix * pmf2.i -
                  pdip.mix * pmf2.d
 
+  if (any(vecTF <- !is.na(pmf0) & pmf0 < 0))
+    pmf0[vecTF] <- NaN
+  if (any(vecTF <- !is.na(pmf0) & pmf0 > 1))
+    pmf0[vecTF] <- NaN
+
   if (log.arg) log(pmf0) else pmf0
 }  # dgaitdlog
 
@@ -1506,14 +1544,14 @@
 
 
 dlog <- function(x, shape, log = FALSE) {
-  if (!is.logical(log.arg <- log) || length(log) != 1)
+  if (!isFALSE(log.arg <- log) && !isTRUE(log))
     stop("bad input for argument 'log'")
   rm(log)
 
 
   N <- max(length(x), length(shape))
-  if (length(x)     != N) x     <- rep_len(x,     N)
-  if (length(shape) != N) shape <- rep_len(shape, N)
+  if (length(x)     < N) x     <- rep_len(x,     N)
+  if (length(shape) < N) shape <- rep_len(shape, N)
   ox <- !is.finite(x)
   zero <- ox | round(x) != x | x < 1
   ans <- rep_len(0.0, length(x))
@@ -1541,8 +1579,8 @@ dlog <- function(x, shape, log = FALSE) {
 
 
   N <- max(length(q), length(shape))
-  if (length(q)     != N) q     <- rep_len(q,     N)
-  if (length(shape) != N) shape <- rep_len(shape, N)
+  if (length(q)     < N) q     <- rep_len(q,     N)
+  if (length(shape) < N) shape <- rep_len(shape, N)
 
 
 
@@ -1636,6 +1674,8 @@ rlog <- function(n, shape) {
            gshape = -expm1(-7 * ppoints(4)),
            zero = NULL) {
 
+  if (is.character(lshape))
+    lshape <- substitute(y9, list(y9 = lshape))
   lshape <- as.list(substitute(lshape))
   eshape <- link2list(lshape)
   lshape <- attr(eshape, "function.name")
