@@ -9,40 +9,46 @@
 
 void vdecccc(int *hqipzx3n, int *exz2jrhq, int *dimm);
 void m2accc(double *m, double *a, int *dimm, int *hqipzx3n,
-       int *exz2jrhq, int *n, int *M, int *rb1onzwu);
+            int *exz2jrhq, int *n, int *M, int *rb1onzwu);
 void a2mccc(double *a, double *m, int *dimm, int *hqipzx3n,
-       int *exz2jrhq, int *n, int *M);
+            int *exz2jrhq, int *n, int *M);
 void mux2ccc(double *cc, double *tlgduey8,
-          double *bzmd6ftv, int *p, int *n, int *M);
+             double *bzmd6ftv, int *p, int *n, int *M);
 void mux22ccc(double *cc, double *tlgduey8, double *bzmd6ftv, int *dimm,
-       int *hqipzx3n, int *exz2jrhq, 
-       int *n, int *M, double *wk, int *rb1onzwu);
+              int *hqipzx3n, int *exz2jrhq, 
+              int *n, int *M, double *wk, int *rb1onzwu);
 void mux5ccc(double *cc, double *x,
-          double *bzmd6ftv, int *M, int *n, int *r,
-          int *dimm,
-          int *dimr,
-          int *matrix,
-          double *wk, double *wk2,
-          int *hqipzx3n_M, int *exz2jrhq_M,
-          int *hqipzx3n_r, int *exz2jrhq_r);
+             double *bzmd6ftv, int *M, int *n, int *r,
+             int *dimm,
+             int *dimr,
+             int *matrix,
+             double *wk, double *wk2,
+             int *hqipzx3n_M, int *exz2jrhq_M,
+             int *hqipzx3n_r, int *exz2jrhq_r);
 void mux55ccc(double *evects, double *evals, double *bzmd6ftv, double *wk, 
-           double *wk2, int *hqipzx3n, int *exz2jrhq,
-           int *M, int *n);
+              double *wk2, int *hqipzx3n, int *exz2jrhq,
+              int *M, int *n);
 void mux7ccc(double *cc, double *x,
-          double *bzmd6ftv, int *M, int *q, int *n, int *r);
+             double *bzmd6ftv, int *M, int *q, int *n, int *r);
 void mux111ccc(double *cc, double *the7mqnvy, int *M, int *R, int *n,
-        double *wkcc, double *wk2, int *hqipzx3n, int *exz2jrhq,
-	    int *dimm, int *rb1onzwu);
+               double *wkcc, double *wk2,
+               int *hqipzx3n, int *exz2jrhq,
+               int *dimm, int *rb1onzwu);
+void mux111ddd(double *cc, double *the7mqnvy, int *M, int *R, int *n,
+               double *wkcc, double *wk2,
+               int *hqipzx3n, int *exz2jrhq,
+               int *dimm, int *rb1onzwu,
+               int *whichj);
 void mux15ccc(double *cc, double *x,
-           double *bzmd6ftv, int *M, int *n);
+              double *bzmd6ftv, int *M, int *n);
 void vcholccc(double *cc, int *M, int *n, int *ok, double *wk,
-           int *hqipzx3n, int *exz2jrhq, int *dimm);
+              int *hqipzx3n, int *exz2jrhq, int *dimm);
 void vforsubccc(double *cc, double *b, int *M, int *n,
-             double *wk, int *hqipzx3n,
-             int *exz2jrhq, int *dimm);
+                double *wk, int *hqipzx3n,
+                int *exz2jrhq, int *dimm);
 void vbacksubccc(double *cc, double *b, int *M, int *n,
-              double *wk, int *hqipzx3n,
-              int *exz2jrhq, int *dimm);
+                 double *wk, int *hqipzx3n,
+                 int *exz2jrhq, int *dimm);
 void tapply_mat1(double *mat, int *nr, int *nc, int *type);
 
 
@@ -67,11 +73,11 @@ void vdecccc(int *hqipzx3n, int *exz2jrhq, int *dimm) {
     hqipzx3n[ayfnwr1v] -= 1;
     exz2jrhq[ayfnwr1v] -= 1;
   }
-}
+}  /* vdecccc */
 
 
 void m2accc(double *m, double *a, int *dimm, int *hqipzx3n,
-         int *exz2jrhq, int *n, int *M, int *rb1onzwu) {
+            int *exz2jrhq, int *n, int *M, int *rb1onzwu) {
   int ayfnwr1v, gp1jxzuh, MM = *M * *M, MMn = *M * *M * *n;
 
   if(*rb1onzwu == 1 || *dimm != *M * (*M + 1) / 2)
@@ -87,11 +93,12 @@ void m2accc(double *m, double *a, int *dimm, int *hqipzx3n,
     a += MM;
     m += *dimm;
   }
-}
+}  /* m2accc */
+
 
 
 void a2mccc(double *a, double *m, int *dimm, int *hqipzx3n,
-         int *exz2jrhq, int *n, int *M) {
+            int *exz2jrhq, int *n, int *M) {
   int ayfnwr1v, gp1jxzuh, MM= *M * *M;
 
   for(gp1jxzuh = 0; gp1jxzuh < *n; gp1jxzuh++) {
@@ -100,13 +107,13 @@ void a2mccc(double *a, double *m, int *dimm, int *hqipzx3n,
     a += MM;
     m += *dimm;
   }
-}
+}  /* a2mccc */
 
 
 
 
 void mux2ccc(double *cc, double *tlgduey8,
-          double *bzmd6ftv, int *p, int *n, int *M) {
+             double *bzmd6ftv, int *p, int *n, int *M) {
   double urohxe6t;
   int ayfnwr1v, yq6lorbx, bpvaqm5z, Mp = *M * *p;
 
@@ -120,13 +127,13 @@ void mux2ccc(double *cc, double *tlgduey8,
     tlgduey8 += *p;
     cc += Mp;
   }
-}
+}  /* mux2ccc */
 
 
 
 void mux22ccc(double *cc, double *tlgduey8, double *bzmd6ftv, int *dimm,
-       int *hqipzx3n, int *exz2jrhq, 
-       int *n, int *M, double *wk, int *rb1onzwu) {
+              int *hqipzx3n, int *exz2jrhq, 
+              int *n, int *M, double *wk, int *rb1onzwu) {
   double urohxe6t;
   int yq6lorbx, bpvaqm5z, gp1jxzuh, one = 1, nzqklc9x;
 
@@ -144,7 +151,7 @@ void mux22ccc(double *cc, double *tlgduey8, double *bzmd6ftv, int *dimm,
     tlgduey8 += *M;
     cc += *dimm;
   }
-}
+}  /* mux22ccc */
 
 
 void mux5ccc(double *cc, double *x,
@@ -202,13 +209,13 @@ void mux5ccc(double *cc, double *x,
     x += Mr;
     bzmd6ftv += (*matrix == 1 ? *dimr : rr);
   }
-}
+}  /* mux5ccc */
 
 
 
 void mux55ccc(double *evects, double *evals, double *bzmd6ftv, double *wk, 
-           double *wk2, int *hqipzx3n, int *exz2jrhq,
-           int *M, int *n) {
+              double *wk2, int *hqipzx3n, int *exz2jrhq,
+              int *M, int *n) {
   double *pd, *pd2, bpvaqm5z;
   int ayfnwr1v, yq6lorbx, gp1jxzuh, urohxe6t, MM = *M * *M, one = 1,
       imk5wjxg = *M * (*M + 1)/2;
@@ -238,14 +245,14 @@ void mux55ccc(double *evects, double *evals, double *bzmd6ftv, double *wk,
     evals += *M;
     evects += MM;
   }
-}
+}  /* mux55ccc */
 
 
 
 
 
 void mux7ccc(double *cc, double *x,
-          double *bzmd6ftv, int *M, int *q, int *n, int *r) {
+             double *bzmd6ftv, int *M, int *q, int *n, int *r) {
   double urohxe6t;
   int ayfnwr1v, yq6lorbx, gp1jxzuh, bpvaqm5z,
       Mq = *M * *q, qr = *q * *r, Mr = *M * *r,
@@ -266,7 +273,7 @@ void mux7ccc(double *cc, double *x,
     bzmd6ftv += Mr;
     x += qr;
   }
-}
+}  /* mux7ccc */
 
 
 
@@ -275,10 +282,10 @@ void mux7ccc(double *cc, double *x,
 
 
 void mux111ccc(double *cc, double *the7mqnvy,
-            int *M, int *R, int *n,
-            double *wkcc, double *wk2,
-            int *hqipzx3n, int *exz2jrhq,
-            int *dimm, int *rb1onzwu) {
+               int *M, int *R, int *n,
+               double *wkcc, double *wk2,
+               int *hqipzx3n, int *exz2jrhq,
+               int *dimm, int *rb1onzwu) {
   double urohxe6t, *pd2, obr6tcexdouble;
   int ayfnwr1v, yq6lorbx, gp1jxzuh, bpvaqm5z,
       MM = *M * *M, MR = *M * *R,
@@ -317,13 +324,62 @@ void mux111ccc(double *cc, double *the7mqnvy,
     } /* ayfnwr1v */
     the7mqnvy += MR;
   }  /* bpvaqm5z */
-}
+}  /* mux111ccc */
+
+
+
+
+
+void mux111ddd(double *cc, double *the7mqnvy,
+               int *M, int *R, int *n,
+               double *wkcc, double *wk2,
+               int *hqipzx3n, int *exz2jrhq,
+               int *dimm, int *rb1onzwu,
+               int *whichj) {
+  double urohxe6t, *pd2, obr6tcexdouble;
+  int ayfnwr1v, yq6lorbx, gp1jxzuh, bpvaqm5z,
+      MM = *M * *M, MR = *M * *R,
+      lowlim;
+
+  vdecccc(hqipzx3n, exz2jrhq, dimm);
+
+  for(ayfnwr1v = 0; ayfnwr1v < MM; ayfnwr1v++)
+    wkcc[ayfnwr1v] = 0.0;
+
+  for(bpvaqm5z = 0; bpvaqm5z < *n; bpvaqm5z++) {
+    for(ayfnwr1v = 0; ayfnwr1v < *dimm; ayfnwr1v++) {
+      if(*rb1onzwu == 0) {
+        obr6tcexdouble = *cc++;
+        wkcc[hqipzx3n[ayfnwr1v] + exz2jrhq[ayfnwr1v] * *M] =
+        wkcc[exz2jrhq[ayfnwr1v] + hqipzx3n[ayfnwr1v] * *M] = obr6tcexdouble;
+      } else {
+        wkcc[hqipzx3n[ayfnwr1v] + exz2jrhq[ayfnwr1v] * *M] = *cc++;
+      }
+    }  /* ayfnwr1v */
+
+    pd2 = the7mqnvy;
+    for(ayfnwr1v = 0; ayfnwr1v < *M; ayfnwr1v++)
+      for(yq6lorbx = 0; yq6lorbx < *R; yq6lorbx++)
+        wk2[ayfnwr1v + yq6lorbx * *M] = *pd2++;
+
+    for(ayfnwr1v = 0; ayfnwr1v < *M; ayfnwr1v++) {
+      lowlim = *rb1onzwu == 0 ? 0 : ayfnwr1v;
+        yq6lorbx = *whichj - 1;  /* Only a single value */
+        urohxe6t = 0.0;
+        for(gp1jxzuh = lowlim; gp1jxzuh < *M; gp1jxzuh++)
+          urohxe6t +=  wk2[gp1jxzuh + yq6lorbx * *M] *
+                    wkcc[ayfnwr1v + gp1jxzuh * *M];
+        the7mqnvy[yq6lorbx + ayfnwr1v * *R] = urohxe6t;
+    } /* ayfnwr1v */
+    the7mqnvy += MR;
+  }  /* bpvaqm5z */
+}  /* mux111ddd */
 
 
 
 
 void mux15ccc(double *cc, double *x,
-           double *bzmd6ftv, int *M, int *n) {
+              double *bzmd6ftv, int *M, int *n) {
   double *pd, *pd2;
   int ayfnwr1v, yq6lorbx, gp1jxzuh, MM = *M * *M;
 
@@ -344,13 +400,13 @@ void mux15ccc(double *cc, double *x,
     bzmd6ftv += MM;
     x += *M;
   }
-}
+}  /* mux15ccc */
 
 
 
 
 void vcholccc(double *cc, int *M, int *n, int *ok, double *wk,
-           int *hqipzx3n, int *exz2jrhq, int *dimm) {
+              int *hqipzx3n, int *exz2jrhq, int *dimm) {
   double urohxe6t, *pd;
   int bpvaqm5z, ayfnwr1v, yq6lorbx, gp1jxzuh, iM, iiM, rb1onzwu = 0, one = 1;
 
@@ -390,13 +446,13 @@ void vcholccc(double *cc, int *M, int *n, int *ok, double *wk,
     cc += *dimm;
     ok++;
   }
-}
+}  /* vcholccc */
 
 
 
 void vforsubccc(double *cc, double *b, int *M, int *n,
-             double *wk, int *hqipzx3n,
-             int *exz2jrhq, int *dimm) {
+                double *wk, int *hqipzx3n,
+                int *exz2jrhq, int *dimm) {
   double urohxe6t, *pd;
   int yq6lorbx, gp1jxzuh, bpvaqm5z, rb1onzwu = 1, one = 1;
 
@@ -415,14 +471,14 @@ void vforsubccc(double *cc, double *b, int *M, int *n,
     cc += *dimm;
     b += *M;
   }
-}
+}  /* vforsubccc */
 
 
 
 
 void vbacksubccc(double *cc, double *b, int *M, int *n,
-              double *wk, int *hqipzx3n,
-              int *exz2jrhq, int *dimm) {
+                 double *wk, int *hqipzx3n,
+                 int *exz2jrhq, int *dimm) {
   double urohxe6t, *pd;
   int yq6lorbx, gp1jxzuh, bpvaqm5z, rb1onzwu = 1, one = 1;
 
@@ -441,7 +497,7 @@ void vbacksubccc(double *cc, double *b, int *M, int *n,
     cc += *dimm;
     b += *M;
   }
-}
+}  /* vbacksubccc */
 
 
 
@@ -469,7 +525,7 @@ void tapply_mat1(double *mat, int *nr, int *nc, int *type) {
 
   if(*type < 1 || *type > 3)
     Rprintf("Error: *type not ezlgm2uped\n");
-}
+}  /* tapply_mat1 */
 
 
 
